function  dataFromFile = readDataFromFile( filename )
%READDATAFROMFILE Reads data from a file of a certain format.
%   This methods reads the data specified in a given file.
%   Right now, we assume that this is a .mat file containing
%   a variable named "pattern". Generally, this can be extended
%   to read any kind of data.
%
%   Input:  filename     -  Name (string) of the file to be read.
%
%   Output: dataFromFile -  Matlab structure containing the data.
%                           Right now, this is only the data array
%                           dataFromFile.data itself.
%           
%                           We may extend this if the given data is
%                           in some container format, e.g., for
%                           experimental data this seems plausible
%                           where the data container may also contain
%                           physicial parameters.
%                   

if exist(filename, 'file') ~= 2
   error('File not found: %s.', filename);
else
    w = load(filename);
    if ~isfield(w,'pattern')
        error('Input file format invalid: variable pattern not found.');
    else
        dataFromFile.data = w.pattern;
    end
end

end

