function  KLDistance  = calculateKLDistance( input_data, Psi )
%CALCULATEKLDISTANCE For a given wave function psi we calculate
%   the discrete Kullback-Leibler distance from psi to the set
%   measurement set M.
%   Based on Approx_PM_Fresnel_Poisson.m by D. Russell Luke.

% Determine all indices where the pointwise squared measurements
% vanish.
I = input_data.problem.data.*input_data.problem.data; 
idxVanishingI = I == 0;                            

% Propagate the wave function into the Fresnel/Fourier domain
% and calculated their pointwise modulus squared values.
propPsi = wavePropagator(input_data, Psi, 1); 
propPsiIntensity = propPsi.*conj(propPsi);    

% Check where those values are equal to the pointwise squared
% measurements and obtain the indices where this is the case.
% Set all entries of the normalizedPropPsiIntensity to 1 where
% this is the case.

normalizedPropPsiIntensity = propPsiIntensity./I;                   
normalizedPropPsiIntensity(idxVanishingI) = 1;              

% Set all indicies of the propagated wave function to zero
% where the pointwise squared measurements are zero.
propPsiIntensity(idxVanishingI) = 0;                

% Determine all entries where the normalizedPropPsiIntensity is
% still zero and set them to 1.
idxNormalizedPropPsiIntensity = normalizedPropPsiIntensity == 0;
normalizedPropPsiIntensity(idxNormalizedPropPsiIntensity) = 1;     

% All entries where either the modulus squared of the propagated
% wave function is equal to the measured magnitude squared or where
% the propagated wave function vanishes is now equal to one. Hence,
% the logarithm of those entries is zero and does not contribute
% to the KLDistance.

normalizedPropPsiIntensity = log(normalizedPropPsiIntensity);
KLDistance = sum(sum(propPsiIntensity.*normalizedPropPsiIntensity + I - propPsiIntensity));

end