clear all
addpath('Algorithms', 'Drivers', 'InputData', 'OutputData', 'Processors', 'ProxOperators', 'Utilities')
addpath(genpath('../ShearLab3Dv11'))

input_data  = simulatedDataCellImage( 'cell256.mat' );

input_data.algorithm.maxit = 2000;
input_data.algorithm.error = 1e-10;
input_data.algorithm.metric = 'norm';



[sizex,sizey] = size(input_data.data);
useGPU        = 0; 
scales        = 4; % number of scales 
input_data.system        = SLgetShearletSystem2D(useGPU,sizex,sizey,scales);

if ~isfield(input_data, 'initialGuess')
    input_data.initialGuess = wavePropagator(input_data,input_data.problem.data); % initial guess is the simple back projection
end

% problemspezifisches mal durchtesten: verschiedene constraintsn

%% shearlet soft thresh + range
input_data.problem.constraint.name      = 'shearlet thresholding and range';     % shearlet thresholding, shearlet thresholding and range,  support, support and range
input_data.problem.constraint.info      = 'soft thresholding';               % optional (depends on constraint name). soft thresholding/ smooth hard
input_data.problem.constraint.parameter = 'const';                   % dynamic = 1/k right now, const 
input_data.problem.constraint.gamma0    = 0.005;                       % initial threshold parameter
input_data.problem.constraint.support   = createSupportIdx(input_data, 0.75, 'ball'); % for the cell and box, we would chose R=0.75.

recDataShearletRangeSoft = RAAR(input_data);

%% shearlet smooth hard
input_data.problem.constraint.name      = 'shearlet thresholding';     % shearlet thresholding, shearlet thresholding and range,  support, support and range
input_data.problem.constraint.info      = 'smooth hard';               % optional (depends on constraint name). soft thresholding/ smooth hard
input_data.problem.constraint.parameter = 'const';                   % dynamic = 1/k right now, const 
input_data.problem.constraint.gamma0    = 0.007;                       % initial threshold parameter
input_data.problem.constraint.support   = createSupportIdx(input_data, 0.75, 'ball'); % for the cell and box, we would chose R=0.75.

recDataShearletSmoothHard = RAAR(input_data);

%% support and range
input_data.problem.constraint.name      = 'support and range';     % shearlet thresholding, shearlet thresholding and range,  support, support and range
if isfield(input_data.problem.constraint, 'info')
    input_data.problem.constraint = rmfield(input_data.problem.constraint, 'info');
end
%input_data.problem.constraint.parameter = 'const';                   % dynamic = 1/k right now, const 
%input_data.problem.constraint.gamma0    = 0.007;                       % initial threshold parameter
input_data.problem.constraint.support   = createSupportIdx(input_data, 0.75, 'ball'); % for the cell and box, we would chose R=0.75.

recDataSupportRange = RAAR(input_data);

%% plots
plotReconstructionResults(recDataSupportRange, recDataShearletRangeSoft, recDataShearletSmoothHard)